@@ -267,6 +267,30 @@ def setProperty(objectID, property, value,platform=None):
     else:
         return res
 
+def setPropertyPerPlatform(object, property, value, platform):
+    """Set a property of a wwise object
+
+    :param object: GUID of the object
+    :param property: Name of the property to set
+    :param value: The value to set for given property
+    :param platform: The platform to apply this property to
+    :return: Result structure or False
+
+    """
+    setPropertyArgs = {
+        "object": object,
+        "property": property,
+        "value": value,
+        "platform": platform
+    }
+    try:
+        res = client.call("ak.wwise.core.object.setProperty",setPropertyArgs)
+    except Exception as ex:
+        print("call error: {}".format(ex))
+        return False
+    else:
+        return res
+
 def setReference(objectID, reference, value,platform=None):
     """Set a reference of a wwise object
 
@@ -370,7 +394,7 @@ def setupImportArgs(parentID, fileList,originalsPath,language="SFX"):
 def deleteWwiseObject(objectID):
     """Delete a wwise object
 
-    :param object: GUID of object to be deleted
+    :param objectID: GUID of object to be deleted
     :return: Result structure or False
 
     """
@@ -717,8 +741,8 @@ def generateSoundbanks(banklist = []):
 def getSoundbanks(objectID,tfrom="id"):
     """ Return all Soundbanks referencing any object of the Work Unit directly
 
+    :param objectID: The object GUID to use in the search
     :param tfrom: Key that determines how obj is used in the search (default=id)
-    :param obj: The object to use in the search
     :return: List of banks directly referencing obj
     """
     BankList =[]
@@ -842,7 +866,7 @@ def removeSwitchContainerAssignment(switch,child):
 def moveWwiseObject(objectID,parent, conflict="replace"):
     """move object to new location under parent
 
-    :param object: ID of wwise object to move
+    :param objectID: ID of wwise object to move
     :param parent: ID of the parent to move object under
     :param conflict: Behaviour for conflicting objects (default = replace)
     :return: Result structure or False
@@ -865,7 +889,7 @@ def moveWwiseObject(objectID,parent, conflict="replace"):
 def renameWwiseObject(objectID,newName):
     """Rename a given object with newName
 
-    :param object: ID of wwise object to rename
+    :param objectID: ID of wwise object to rename
     :param newName: The new name of the wwise object
     :return: Result structure or False
 
@@ -886,7 +910,7 @@ def renameWwiseObject(objectID,newName):
 def copyWwiseObject(objectID, parent, conflict="replace"):
     """copy object to new location under parent
     
-    :param object: ID of wwise object to copy
+    :param objectID: ID of wwise object to copy
     :param parent: ID of the parent to paste object under
     :param conflict: Behaviour for conflicting objects (default = replace)
     :return: Result structure or False
